package cz.zcu.mjaneck.bak_prace.app;

import javafx.collections.ObservableMap;
import javafx.scene.chart.XYChart.Series;
import cz.zcu.mjaneck.bak_prace.communication.ArduinoCommunicationThread;

/**
 * Třída pro správu měření
 */
public class MeasurementManager {

    /** Instance třídy */
    private static MeasurementManager INSTANCE;
    /** Mapa kapacit */
    private ObservableMap<String, Double> capacityMap;
    /** Proměnná obsahující naměřené hodnoty s časem zaznamenání */
    private Series<Number, Number> series;
    /** Zvolený port */
    private String port;
    /** Zvolená velikost proudu */
    private int current;
    /** Vlákno pro komunikaci s Arduinem */
    private ArduinoCommunicationThread commThread;

    /**
     * Zahájí měření
     */
    public void startMeasurement() {
        commThread = new ArduinoCommunicationThread(series, port, current, capacityMap);
        Thread t = new Thread(commThread);
        t.start();
    }

    /**
     * Ukončí měření
     */
    public void stopMeasurement() {
        if (this.commThread == null)
            return;

        this.port = null;
        this.series = null;
        this.commThread.stopThread();
        this.commThread = null;
    }

    /**
     * Vrací instanci třídy
     * @return - instance třídy
     */
    public static MeasurementManager getInstance() {

        if (INSTANCE == null)
            INSTANCE = new MeasurementManager();

        return INSTANCE;
    }

    /**
     * Nastaví pole pro zaznamenávaní hodnot a času
     * @param series - pole
     */
    public void setSeries(Series<Number, Number> series) {
        this.series = series;
    }

    /**
     * Nastaví port
     * @param port - port
     */
    public void setPort(String port) {
        this.port = port;
    }

    /**
     * Nastaví proud
     * @param current - proud
     */
    public void setCurrent(int current) {
        this.current = current;
    }

    /**
     * Nastaví mapu kapacit
     * @param capacityMap - mapa kapacit
     */
    public void setCapacityMap(ObservableMap<String, Double> capacityMap) {
        this.capacityMap = capacityMap;
    }

    /**
     * Vrací čas začátku
     * @return - čas začátku
     */
    public long getStartTime() {
        if (commThread != null)
            return commThread.getStartTime();
        return 0;
    }
}
